@@ -25,18 +25,17 @@
 """
 
 import dns
+import dns.flags
+import dns.message
 import dns.opcode
 import dns.rcode
-import dns.message
-import dns.flags
-import dns.opcode
 from oslo_config import cfg
 from oslo_log import log as logging
 
-from designate import utils
-from designate import dnsutils
 from designate.backend import agent_backend
 import designate.backend.private_codes as pcodes
+from designate import dnsutils
+from designate import utils
 
 LOG = logging.getLogger(__name__)
 CONF = cfg.CONF
@@ -104,7 +103,9 @@ class RequestHandler(object):
 
         question = request.question[0]
         requester = request.environ['addr'][0]
-        zone_name = question.name.to_text().decode('utf-8')
+        zone_name = question.name.to_text()
+        if isinstance(zone_name, bytes):
+            zone_name = zone_name.decode('utf-8')
 
         if not self._allowed(request, requester, "CREATE", zone_name):
             response.set_rcode(dns.rcode.from_text("REFUSED"))
@@ -155,7 +156,9 @@ class RequestHandler(object):
 
         question = request.question[0]
         requester = request.environ['addr'][0]
-        zone_name = question.name.to_text().decode('utf-8')
+        zone_name = question.name.to_text()
+        if isinstance(zone_name, bytes):
+            zone_name = zone_name.decode('utf-8')
 
         if not self._allowed(request, requester, "NOTIFY", zone_name):
             response.set_rcode(dns.rcode.from_text("REFUSED"))
@@ -182,7 +185,7 @@ class RequestHandler(object):
 
         try:
             zone = dnsutils.do_axfr(zone_name, self.masters,
-                source=self.transfer_source)
+                                    source=self.transfer_source)
             self.backend.update_zone(zone)
         except Exception:
             response.set_rcode(dns.rcode.from_text("SERVFAIL"))
@@ -206,7 +209,9 @@ class RequestHandler(object):
 
         question = request.question[0]
         requester = request.environ['addr'][0]
-        zone_name = question.name.to_text().decode('utf-8')
+        zone_name = question.name.to_text()
+        if isinstance(zone_name, bytes):
+            zone_name = zone_name.decode('utf-8')
 
         if not self._allowed(request, requester, "DELETE", zone_name):
             response.set_rcode(dns.rcode.from_text("REFUSED"))
