@@ -13,19 +13,13 @@
 # WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 # License for the specific language governing permissions and limitations
 # under the License.
+from oslo_config import cfg
 import pecan
 import pecan.deploy
-from oslo_config import cfg
 
 from designate.api.v2 import patches
 
 
-cfg.CONF.register_opts([
-    cfg.BoolOpt('pecan_debug', default=False,
-                help='Pecan HTML Debug Interface'),
-], group='service:api')
-
-
 def setup_app(pecan_config):
     config = dict(pecan_config)
 
