@@ -32,7 +32,6 @@ import pecan.routing
 
 from designate import exceptions
 from designate.central import rpcapi as central_rpcapi
-from designate.pool_manager import rpcapi as pool_mgr_rpcapi
 
 
 class RestController(pecan.rest.RestController):
@@ -50,10 +49,6 @@ class RestController(pecan.rest.RestController):
     def central_api(self):
         return central_rpcapi.CentralAPI.get_instance()
 
-    @property
-    def pool_mgr_api(self):
-        return pool_mgr_rpcapi.PoolManagerAPI.get_instance()
-
     def _apply_filter_params(self, params, accepted_filters, criterion):
         invalid = []
         for k in params:
@@ -67,7 +62,7 @@ class RestController(pecan.rest.RestController):
         else:
             return criterion
 
-    def _handle_post(self, method, remainder):
+    def _handle_post(self, method, remainder, request=None):
         '''
         Routes ``POST`` actions to the appropriate controller.
         '''
@@ -80,7 +75,8 @@ class RestController(pecan.rest.RestController):
 
         controller = getattr(self, remainder[0], None)
         if controller and not inspect.ismethod(controller):
-            return pecan.routing.lookup_controller(controller, remainder[1:])
+            return pecan.routing.lookup_controller(controller, remainder[1:],
+                                                   request=request)
 
         # finally, check for the regular post_one/post requests
         controller = self._find_controller('post_one', 'post')
@@ -89,7 +85,7 @@ class RestController(pecan.rest.RestController):
 
         pecan.abort(405)
 
-    def _handle_patch(self, method, remainder):
+    def _handle_patch(self, method, remainder, request=None):
         '''
         Routes ``PATCH`` actions to the appropriate controller.
         '''
@@ -102,7 +98,8 @@ class RestController(pecan.rest.RestController):
 
         controller = getattr(self, remainder[0], None)
         if controller and not inspect.ismethod(controller):
-            return pecan.routing.lookup_controller(controller, remainder[1:])
+            return pecan.routing.lookup_controller(controller, remainder[1:],
+                                                   request=request)
 
         # finally, check for the regular patch_one/patch requests
         controller = self._find_controller('patch_one', 'patch')
@@ -111,7 +108,7 @@ class RestController(pecan.rest.RestController):
 
         pecan.abort(405)
 
-    def _handle_put(self, method, remainder):
+    def _handle_put(self, method, remainder, request=None):
         '''
         Routes ``PUT`` actions to the appropriate controller.
         '''
@@ -124,7 +121,8 @@ class RestController(pecan.rest.RestController):
 
         controller = getattr(self, remainder[0], None)
         if controller and not inspect.ismethod(controller):
-            return pecan.routing.lookup_controller(controller, remainder[1:])
+            return pecan.routing.lookup_controller(controller, remainder[1:],
+                                                   request=request)
 
         # finally, check for the regular put_one/put requests
         controller = self._find_controller('put_one', 'put')
@@ -133,7 +131,7 @@ class RestController(pecan.rest.RestController):
 
         pecan.abort(405)
 
-    def _handle_delete(self, method, remainder):
+    def _handle_delete(self, method, remainder, request=None):
         '''
         Routes ``DELETE`` actions to the appropriate controller.
         '''
@@ -146,7 +144,8 @@ class RestController(pecan.rest.RestController):
 
         controller = getattr(self, remainder[0], None)
         if controller and not inspect.ismethod(controller):
-            return pecan.routing.lookup_controller(controller, remainder[1:])
+            return pecan.routing.lookup_controller(controller, remainder[1:],
+                                                   request=request)
 
         # finally, check for the regular delete_one/delete requests
         controller = self._find_controller('delete_one', 'delete')
