@@ -16,17 +16,17 @@
 from oslo_config import cfg
 from stevedore import named
 
-from designate.api.v2.controllers import limits
-from designate.api.v2.controllers import reverse
-from designate.api.v2.controllers import tlds
 from designate.api.v2.controllers import blacklists
 from designate.api.v2.controllers import errors
+from designate.api.v2.controllers import limits
 from designate.api.v2.controllers import pools
-from designate.api.v2.controllers import service_status
-from designate.api.v2.controllers import zones
-from designate.api.v2.controllers import tsigkeys
-from designate.api.v2.controllers import recordsets
 from designate.api.v2.controllers import quotas
+from designate.api.v2.controllers import recordsets
+from designate.api.v2.controllers import reverse
+from designate.api.v2.controllers import service_status
+from designate.api.v2.controllers import tlds
+from designate.api.v2.controllers import tsigkeys
+from designate.api.v2.controllers import zones
 
 
 class RootController(object):
@@ -58,6 +58,13 @@ class RootController(object):
     errors = errors.ErrorsController()
     pools = pools.PoolsController()
     service_statuses = service_status.ServiceStatusController()
+
+    # This is a compatibility workaround for a mistake published in the
+    # Designate API reference that listed the URL path as /v2/service_status
+    # instead of /v2/service_statuses as it was implemented.
+    # https://bugs.launchpad.net/designate/+bug/1919183
+    service_status = service_statuses
+
     tsigkeys = tsigkeys.TsigKeysController()
     recordsets = recordsets.RecordSetsViewController()
     quotas = quotas.QuotasController()
