@@ -13,18 +13,18 @@
 # WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 # License for the specific language governing permissions and limitations
 # under the License.
-import pecan
 from oslo_config import cfg
 from oslo_log import log as logging
+import pecan
 
-from designate import exceptions
-from designate import utils
 from designate.api.v2.controllers import rest
+from designate.api.v2.controllers.zones import nameservers
 from designate.api.v2.controllers.zones import recordsets
 from designate.api.v2.controllers.zones import tasks
-from designate.api.v2.controllers.zones import nameservers
+from designate import exceptions
 from designate import objects
 from designate.objects.adapters import DesignateAdapter
+from designate import utils
 
 CONF = cfg.CONF
 
@@ -54,10 +54,7 @@ class ZonesController(rest.RestController):
 
         LOG.info("Retrieved %(zone)s", {'zone': zone})
 
-        return DesignateAdapter.render(
-            'API_v2',
-            zone,
-            request=request)
+        return DesignateAdapter.render('API_v2', zone, request=request)
 
     @pecan.expose(template='json:', content_type='application/json')
     def get_all(self, **params):
@@ -155,7 +152,7 @@ class ZonesController(rest.RestController):
             # 1) "Nested" resources? records inside a recordset.
             # 2) What to do when a zone doesn't exist in the first place?
             # 3) ...?
-            raise NotImplemented('json-patch not implemented')
+            raise NotImplementedError('json-patch not implemented')
         else:
             # Update the zone object with the new values
             zone = DesignateAdapter.parse('API_v2', body, zone)
