@@ -13,14 +13,13 @@
 # WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 # License for the specific language governing permissions and limitations
 # under the License.
-import six
-import pecan
 from oslo_log import log as logging
+import pecan
 
-from designate import exceptions
-from designate import utils
 from designate.api.v2.controllers import rest
+from designate import exceptions
 from designate.objects.adapters import DesignateAdapter
+from designate import utils
 
 LOG = logging.getLogger(__name__)
 
@@ -42,10 +41,7 @@ class ZoneImportController(rest.RestController):
 
         LOG.info("Retrieved %(import)s", {'import': zone_import})
 
-        return DesignateAdapter.render(
-            'API_v2',
-            zone_import,
-            request=request)
+        return DesignateAdapter.render('API_v2', zone_import, request=request)
 
     @pecan.expose(template='json:', content_type='application/json')
     def get_all(self, **params):
@@ -66,10 +62,7 @@ class ZoneImportController(rest.RestController):
 
         LOG.info("Retrieved %(imports)s", {'imports': zone_imports})
 
-        return DesignateAdapter.render(
-            'API_v2',
-            zone_imports,
-            request=request)
+        return DesignateAdapter.render('API_v2', zone_imports, request=request)
 
     @pecan.expose(template='json:', content_type='application/json')
     def post_all(self):
@@ -77,10 +70,7 @@ class ZoneImportController(rest.RestController):
         request = pecan.request
         response = pecan.response
         context = request.environ['context']
-        if six.PY2:
-            body = request.body
-        else:
-            body = request.body.decode('utf-8')
+        body = request.body.decode('utf-8')
 
         if request.content_type != 'text/dns':
             raise exceptions.UnsupportedContentType(
@@ -93,8 +83,8 @@ class ZoneImportController(rest.RestController):
 
         LOG.info("Created %(zone_import)s", {'zone_import': zone_import})
 
-        zone_import = DesignateAdapter.render(
-            'API_v2', zone_import, request=request)
+        zone_import = DesignateAdapter.render('API_v2', zone_import,
+                                              request=request)
 
         response.headers['Location'] = zone_import['links']['self']
         # Prepare and return the response body
