@@ -20,16 +20,15 @@ Bind 9 backend. Create and delete zones by executing rndc
 
 import random
 
-import six
+import subprocess
+
 from oslo_log import log as logging
 from oslo_utils import strutils
 
+from designate.backend import base
+from designate.conf.mdns import DEFAULT_MDNS_PORT
 from designate import exceptions
 from designate import utils
-from designate.backend import base
-from designate.utils import DEFAULT_MDNS_PORT
-from designate.i18n import _LI
-
 
 LOG = logging.getLogger(__name__)
 DEFAULT_MASTER_PORT = DEFAULT_MDNS_PORT
@@ -53,6 +52,9 @@ class Bind9Backend(base.Backend):
                                   self.options.get('clean_zonefile', 'false'))
 
         self._rndc_call_base = self._generate_rndc_base_call()
+        self._rndc_timeout = self.options.get('rndc_timeout', None)
+        if self._rndc_timeout == 0:
+            self._rndc_timeout = None
 
     def _generate_rndc_base_call(self):
         """Generate argument list to execute rndc"""
@@ -98,12 +100,31 @@ class Bind9Backend(base.Backend):
             self._execute_rndc(rndc_op)
         except exceptions.Backend as e:
             # If create fails because the zone exists, don't reraise
-            if "already exists" not in six.text_type(e):
+            if "already exists" not in str(e):
+                LOG.warning('RNDC call failure: %s', e)
                 raise
 
-        self.mdns_api.notify_zone_changed(
-            context, zone, self._host, self._port, self.timeout,
-            self.retry_interval, self.max_retries, self.delay)
+    def get_zone(self, context, zone):
+        """Returns True if zone exists and False if not"""
+        LOG.debug('Get Zone')
+
+        view = 'in %s' % self._view if self._view else ''
+
+        rndc_op = [
+            'showzone',
+            '%s %s' % (zone['name'].rstrip('.'), view),
+        ]
+        try:
+            self._execute_rndc(rndc_op)
+        except exceptions.Backend as e:
+            if "not found" in str(e):
+                LOG.debug('Zone %s not found on the backend', zone['name'])
+                return False
+            else:
+                LOG.warning('RNDC call failure: %s', e)
+                raise e
+
+        return True
 
     def delete_zone(self, context, zone):
         """Delete a new Zone by executin rndc
@@ -124,9 +145,54 @@ class Bind9Backend(base.Backend):
             self._execute_rndc(rndc_op)
         except exceptions.Backend as e:
             # If zone is already deleted, don't reraise
-            if "not found" not in six.text_type(e):
+            if "not found" not in str(e):
+                LOG.warning('RNDC call failure: %s', e)
                 raise
 
+    def update_zone(self, context, zone):
+        """
+        Update a DNS zone.
+
+        This will execute a rndc modzone if the zone
+        already exists but masters might need to be refreshed.
+        Or, will create the zone if it does not exist.
+
+        :param context: Security context information.
+        :param zone: the DNS zone.
+        """
+        LOG.debug('Update Zone')
+
+        if not self.get_zone(context, zone):
+            # If zone does not exist yet, create it
+            self.create_zone(context, zone)
+            # Newly created zone won't require an update
+            return
+
+        masters = []
+        for master in self.masters:
+            host = master['host']
+            port = master['port']
+            masters.append('%s port %s' % (host, port))
+
+        # Ensure different MiniDNS instances are targeted for AXFRs
+        random.shuffle(masters)
+
+        view = 'in %s' % self._view if self._view else ''
+
+        rndc_op = [
+            'modzone',
+            '%s %s { type slave; masters { %s;}; file "slave.%s%s"; };' %
+            (zone['name'].rstrip('.'), view, '; '.join(masters), zone['name'],
+             zone['id']),
+        ]
+
+        try:
+            self._execute_rndc(rndc_op)
+        except exceptions.Backend as e:
+            LOG.warning("Error updating zone: %s", e)
+            pass
+        super().update_zone(context, zone)
+
     def _execute_rndc(self, rndc_op):
         """Execute rndc
 
@@ -137,8 +203,9 @@ class Bind9Backend(base.Backend):
         """
         try:
             rndc_call = self._rndc_call_base + rndc_op
-            LOG.debug('Executing RNDC call: %r', rndc_call)
-            utils.execute(*rndc_call)
-        except utils.processutils.ProcessExecutionError as e:
-            LOG.info(_LI('RNDC call failure: %s'), e)
+            LOG.debug('Executing RNDC call: %r with timeout %s',
+                rndc_call, self._rndc_timeout)
+            utils.execute(*rndc_call, timeout=self._rndc_timeout)
+        except (utils.processutils.ProcessExecutionError,
+                subprocess.TimeoutExpired) as e:
             raise exceptions.Backend(e)
