@@ -18,13 +18,12 @@ import sys
 from oslo_log import log as logging
 from oslo_reports import guru_meditation_report as gmr
 
+from designate.agent import service as agent_service
 import designate.conf
 from designate import heartbeat_emitter
-from designate import hookpoints
 from designate import service
 from designate import utils
 from designate import version
-from designate.agent import service as agent_service
 
 
 CONF = designate.conf.CONF
@@ -36,8 +35,6 @@ def main():
     logging.setup(CONF, 'designate')
     gmr.TextGuruMeditation.setup_autorun(version)
 
-    hookpoints.log_hook_setup()
-
     server = agent_service.Service()
     heartbeat = heartbeat_emitter.get_heartbeat_emitter(server.service_name)
     service.serve(server, workers=CONF['service:agent'].workers)
