@@ -20,11 +20,10 @@ from oslo_reports import guru_meditation_report as gmr
 
 import designate.conf
 from designate import heartbeat_emitter
-from designate import hookpoints
+from designate.mdns import service as mdns_service
 from designate import service
 from designate import utils
 from designate import version
-from designate.mdns import service as mdns_service
 
 
 CONF = designate.conf.CONF
@@ -36,8 +35,6 @@ def main():
     logging.setup(CONF, 'designate')
     gmr.TextGuruMeditation.setup_autorun(version)
 
-    hookpoints.log_hook_setup()
-
     server = mdns_service.Service()
     heartbeat = heartbeat_emitter.get_heartbeat_emitter(server.service_name)
     service.serve(server, workers=CONF['service:mdns'].workers)
