@@ -15,33 +15,27 @@
 # under the License.
 import random
 import socket
-import base64
-import time
 from threading import Lock
+import time
 
-import six
 import dns
 import dns.exception
+import dns.query
+import dns.rdatatype
 import dns.zone
 import eventlet
-from dns import rdatatype
 from oslo_log import log as logging
-from oslo_config import cfg
+from oslo_serialization import base64
 
+import designate.conf
 from designate import context
 from designate import exceptions
 from designate import objects
 
+CONF = designate.conf.CONF
 LOG = logging.getLogger(__name__)
 
 
-util_opts = [
-    cfg.IntOpt('xfr_timeout', help="Timeout in seconds for XFR's.", default=10)
-]
-
-cfg.CONF.register_opts(util_opts)
-
-
 class DNSMiddleware(object):
     """Base DNS Middleware class with some utility methods"""
     def __init__(self, application):
@@ -148,7 +142,6 @@ class TsigInfoMiddleware(DNSMiddleware):
 
     def __init__(self, application, storage):
         super(TsigInfoMiddleware, self).__init__(application)
-
         self.storage = storage
 
     def process_request(self, request):
@@ -156,7 +149,10 @@ class TsigInfoMiddleware(DNSMiddleware):
             return None
 
         try:
-            criterion = {'name': request.keyname.to_text(True).decode('utf-8')}
+            name = request.keyname.to_text(True)
+            if isinstance(name, bytes):
+                name = name.decode('utf-8')
+            criterion = {'name': name}
             tsigkey = self.storage.find_tsigkey(
                     context.get_current(), criterion)
 
@@ -182,11 +178,14 @@ class TsigKeyring(object):
 
     def get(self, key, default=None):
         try:
-            criterion = {'name': key.to_text(True).decode('utf-8')}
+            name = key.to_text(True)
+            if isinstance(name, bytes):
+                name = name.decode('utf-8')
+            criterion = {'name': name}
             tsigkey = self.storage.find_tsigkey(
                 context.get_current(), criterion)
 
-            return base64.decodestring(tsigkey.secret)
+            return base64.decode_as_bytes(tsigkey.secret)
 
         except exceptions.TsigKeyNotFound:
             return default
@@ -241,7 +240,7 @@ class LimitNotifyMiddleware(DNSMiddleware):
     def __init__(self, application):
         super(LimitNotifyMiddleware, self).__init__(application)
 
-        self.delay = cfg.CONF['service:agent'].notify_delay
+        self.delay = CONF['service:agent'].notify_delay
         self.locker = ZoneLock(self.delay)
 
     def process_request(self, request):
@@ -249,7 +248,9 @@ class LimitNotifyMiddleware(DNSMiddleware):
         if opcode != dns.opcode.NOTIFY:
             return None
 
-        zone_name = request.question[0].name.to_text().decode('utf-8')
+        zone_name = request.question[0].name.to_text()
+        if isinstance(zone_name, bytes):
+            zone_name = zone_name.decode('utf-8')
 
         if self.locker.acquire(zone_name):
             time.sleep(self.delay)
@@ -271,11 +272,18 @@ def from_dnspython_zone(dnspython_zone):
     if soa is None:
         raise exceptions.BadRequest('An SOA record is required')
     if soa.ttl == 0:
-        soa.ttl = cfg.CONF['service:central'].min_ttl
-    email = soa[0].rname.to_text(omit_final_dot=True).decode('utf-8')
+        soa.ttl = CONF['service:central'].min_ttl
+    email = soa[0].rname.to_text(omit_final_dot=True)
+    if isinstance(email, bytes):
+        email = email.decode('utf-8')
     email = email.replace('.', '@', 1)
+
+    name = dnspython_zone.origin.to_text()
+    if isinstance(name, bytes):
+        name = name.decode('utf-8')
+
     values = {
-        'name': dnspython_zone.origin.to_text().decode('utf-8'),
+        'name': name,
         'email': email,
         'ttl': soa.ttl,
         'serial': soa[0].serial,
@@ -293,7 +301,7 @@ def from_dnspython_zone(dnspython_zone):
 def dnspyrecords_to_recordsetlist(dnspython_records):
     rrsets = objects.RecordSetList()
 
-    for rname in six.iterkeys(dnspython_records):
+    for rname in dnspython_records.keys():
         for rdataset in dnspython_records[rname]:
             rrset = dnspythonrecord_to_recordset(rname, rdataset)
 
@@ -305,14 +313,18 @@ def dnspyrecords_to_recordsetlist(dnspython_records):
 
 
 def dnspythonrecord_to_recordset(rname, rdataset):
-    record_type = rdatatype.to_text(rdataset.rdtype)
+    record_type = dns.rdatatype.to_text(rdataset.rdtype)
+
+    name = rname.to_text()
+    if isinstance(name, bytes):
+        name = name.decode('utf-8')
 
     # Create the other recordsets
+
     values = {
-        'name': rname.to_text().decode('utf-8'),
+        'name': name,
         'type': record_type
     }
-
     if rdataset.ttl != 0:
         values['ttl'] = rdataset.ttl
 
@@ -325,49 +337,145 @@ def dnspythonrecord_to_recordset(rname, rdataset):
     return rrset
 
 
-def do_axfr(zone_name, servers, timeout=None, source=None):
+def xfr_timeout():
+    if CONF['service:mdns'].xfr_timeout is not None:
+        return CONF['service:mdns'].xfr_timeout
+    else:
+        return CONF['service:worker'].xfr_timeout
+
+
+def do_axfr(zone_name, servers, source=None):
     """
     Requests an AXFR for a given zone name and process the response
 
     :returns: Zone instance from dnspython
     """
     random.shuffle(servers)
-    timeout = timeout or cfg.CONF["service:mdns"].xfr_timeout
 
     xfr = None
-
     for srv in servers:
-        to = eventlet.Timeout(timeout)
-        log_info = {'name': zone_name, 'host': srv}
-        try:
-            LOG.info("Doing AXFR for %(name)s from %(host)s", log_info)
-
-            xfr = dns.query.xfr(srv['host'], zone_name, relativize=False,
-                                timeout=1, port=srv['port'], source=source)
-            raw_zone = dns.zone.from_xfr(xfr, relativize=False)
-            break
-        except eventlet.Timeout as t:
-            if t == to:
-                LOG.error("AXFR timed out for %(name)s from %(host)s",
-                          log_info)
-                continue
-        except dns.exception.FormError:
-            LOG.error("Zone %(name)s is not present on %(host)s."
-                      "Trying next server.", log_info)
-        except socket.error:
-            LOG.error("Connection error when doing AXFR for %(name)s from "
-                      "%(host)s", log_info)
-        except Exception:
-            LOG.exception("Problem doing AXFR %(name)s from %(host)s. "
+        for address in get_ip_addresses(srv['host']):
+            to = eventlet.Timeout(xfr_timeout())
+            log_info = {'name': zone_name, 'host': srv, 'address': address}
+            try:
+                LOG.info(
+                    'Doing AXFR for %(name)s from %(host)s %(address)s',
+                    log_info
+                )
+                xfr = dns.query.xfr(
+                    address, zone_name, relativize=False, timeout=1,
+                    port=srv['port'], source=source
+                )
+                raw_zone = dns.zone.from_xfr(xfr, relativize=False)
+                LOG.debug("AXFR Successful for %s", raw_zone.origin.to_text())
+                return raw_zone
+            except eventlet.Timeout as t:
+                if t == to:
+                    LOG.error("AXFR timed out for %(name)s from %(host)s",
+                              log_info)
+                    continue
+            except dns.exception.FormError:
+                LOG.error("Zone %(name)s is not present on %(host)s."
                           "Trying next server.", log_info)
-        finally:
-            to.cancel()
-        continue
+            except socket.error:
+                LOG.error("Connection error when doing AXFR for %(name)s from "
+                          "%(host)s", log_info)
+            except Exception:
+                LOG.exception("Problem doing AXFR %(name)s from %(host)s. "
+                              "Trying next server.", log_info)
+            finally:
+                to.cancel()
+
+    raise exceptions.XFRFailure(
+        "XFR failed for %(name)s. No servers in %(servers)s was reached." %
+        {"name": zone_name, "servers": servers}
+    )
+
+
+def prepare_dns_message(zone_name, rdatatype, opcode):
+    """
+    Create a dns message using dnspython
+    """
+    dns_message = dns.message.make_query(zone_name, rdatatype)
+    dns_message.set_opcode(opcode)
+    return dns_message
+
+
+def notify(zone_name, host, port=53, timeout=10):
+    """
+    Create a NOTIFY message and send it
+    """
+    dns_message = prepare_dns_message(
+        zone_name, rdatatype=dns.rdatatype.SOA, opcode=dns.opcode.NOTIFY
+    )
+    return send_dns_message(dns_message, host, port=port, timeout=timeout)
+
+
+def soa_query(zone_name, host, port=53, timeout=10):
+    """
+    Create a SOA Query message and send it
+    """
+    dns_message = prepare_dns_message(
+        zone_name, rdatatype=dns.rdatatype.SOA, opcode=dns.opcode.QUERY
+    )
+    return send_dns_message(dns_message, host, port=port, timeout=timeout)
+
+
+def use_all_tcp():
+    if CONF['service:mdns'].all_tcp is not None:
+        return CONF['service:mdns'].all_tcp
     else:
-        raise exceptions.XFRFailure(
-            "XFR failed for %(name)s. No servers in %(servers)s was reached." %
-            {"name": zone_name, "servers": servers})
+        return CONF['service:worker'].all_tcp
 
-    LOG.debug("AXFR Successful for %s", raw_zone.origin.to_text())
 
-    return raw_zone
+def send_dns_message(dns_message, host, port=53, timeout=10):
+    """
+    Send the dns message and return the response
+
+    :return: dns.Message of the response to the dns query
+    """
+    ip_address = get_ip_address(host)
+    # This can raise some exceptions, but we'll catch them elsewhere
+    if not use_all_tcp():
+        return dns.query.udp(
+            dns_message, ip_address, port=port, timeout=timeout)
+    return dns.query.tcp(
+        dns_message, ip_address, port=port, timeout=timeout)
+
+
+def get_serial(zone_name, host, port=53):
+    """
+    Possibly raises dns.exception.Timeout or dns.query.BadResponse.
+    Possibly returns 0 if, e.g., the answer section is empty.
+    """
+    resp = soa_query(zone_name, host, port=port)
+    if not resp.answer:
+        return 0
+    rdataset = resp.answer[0].to_rdataset()
+    if not rdataset:
+        return 0
+    return rdataset[0].serial
+
+
+def get_ip_address(ip_address_or_hostname):
+    """
+    Provide an ip or hostname and return a valid ip4 or ipv6 address.
+
+    :return: ip address
+    """
+    addresses = get_ip_addresses(ip_address_or_hostname)
+    if not addresses:
+        return None
+    return addresses[0]
+
+
+def get_ip_addresses(ip_address_or_hostname):
+    """
+    Provide an ip or hostname and return all valid ip4 or ipv6 addresses.
+
+    :return: ip addresses
+    """
+    addresses = []
+    for res in socket.getaddrinfo(ip_address_or_hostname, 0):
+        addresses.append(res[4][0])
+    return list(set(addresses))
