@@ -13,8 +13,7 @@
 # WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 # License for the specific language governing permissions and limitations
 # under the License.
-from designate import policy
-from designate.context import DesignateContext
+from designate import context
 
 
 # Decorators for actions
@@ -37,6 +36,11 @@ def name(name):
 
 class Commands(object):
     def __init__(self):
-        self.context = DesignateContext.get_admin_context(
-            request_id='designate-manage')
-        policy.init()
+        self.context = context.DesignateContext.get_admin_context(
+            request_id='designate-manage'
+        )
+        self.output_message = ['']
+
+    def _print_result(self):
+        for message in self.output_message:
+            print(message)
