@@ -12,16 +12,17 @@
 #    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 #    License for the specific language governing permissions and limitations
 #    under the License.
-import six
+
 from oslo_log import log as logging
-from oslo_versionedobjects import exception
 from oslo_utils import excutils
-from designate.i18n import _
 from oslo_versionedobjects import base
 from oslo_versionedobjects.base import VersionedObjectDictCompat as DictObjectMixin  # noqa
+from oslo_versionedobjects import exception
+from oslo_versionedobjects import fields as ovoo_fields
 
-from designate.objects import fields
 from designate import exceptions
+from designate.objects import fields
+
 
 LOG = logging.getLogger(__name__)
 
@@ -53,16 +54,15 @@ class DesignateObject(base.VersionedObject):
         self.FIELDS = self.fields
 
     @classmethod
-    def _make_obj_str(cls, keys):
-        msg = "<%(name)s" % {'name': cls.obj_name()}
-        for key in keys:
-            msg += " {0}:'%({0})s'".format(key)
+    def _make_obj_str(cls, data):
+        msg = "<%s" % cls.obj_name()
+        for key in cls.STRING_KEYS:
+            msg += " %s:'%s'" % (key, data.get(key))
         msg += ">"
         return msg
 
-    def __str__(self):
-        return (self._make_obj_str(self.STRING_KEYS)
-                % self)
+    def __repr__(self):
+        return self._make_obj_str(self.to_dict())
 
     def save(self, context):
         pass
@@ -128,13 +128,13 @@ class DesignateObject(base.VersionedObject):
 
     def __setattr__(self, name, value):
         """Enforces all object attributes are private or well defined"""
-        if not (name[0:5] == '_obj_'
-                or name[0:7] == '_change'
-                or name == '_context'
-                or name in list(six.iterkeys(self.fields))
-                or name == 'FIELDS'
-                or name == 'VERSION'
-                or name == 'fields'):
+        if not (name[0:5] == '_obj_' or
+                name[0:7] == '_change' or
+                name == '_context' or
+                name in list(self.fields.keys()) or
+                name == 'FIELDS' or
+                name == 'VERSION' or
+                name == 'fields'):
             raise AttributeError(
                 "Designate object '%(type)s' has no"
                 "attribute '%(name)s'" % {
@@ -152,9 +152,6 @@ class DesignateObject(base.VersionedObject):
     def __ne__(self, other):
         return not (self.__eq__(other))
 
-    def __repr__(self):
-        return "OVO Objects"
-
     # TODO(daidv): all of bellow functions should
     # be removed when we completed migration.
     def nested_sort(self, key, value):
@@ -226,10 +223,10 @@ class DesignateObject(base.VersionedObject):
                     continue
 
                 # Reset straight Object and ListOfObjects fields
-                if isinstance(self.fields[field], self.obj_fields.ObjectField):
+                if isinstance(self.fields[field], ovoo_fields.ObjectField):
                     value.obj_reset_changes(recursive=True)
                 elif isinstance(self.fields[field],
-                                self.obj_fields.ListOfObjectsField):
+                                ovoo_fields.ListOfObjectsField):
                     for thing in value:
                         thing.obj_reset_changes(recursive=True)
 
@@ -243,7 +240,7 @@ class DesignateObject(base.VersionedObject):
 
     def obj_get_original_value(self, field):
         """Returns the original value of a field."""
-        if field in list(six.iterkeys(self._obj_original_values)):
+        if field in list(self._obj_original_values.keys()):
             return self._obj_original_values[field]
         elif self.obj_attr_is_set(field):
             return getattr(self, field)
@@ -286,7 +283,7 @@ class DesignateObject(base.VersionedObject):
                 else:
                     try:
                         field.coerce(self, name, value)  # Check value
-                    except Exception as e:
+                    except Exception:
                         raise exceptions.InvalidObject(
                             "{} is invalid".format(name))
             elif not field.nullable:
@@ -329,7 +326,7 @@ class ListObjectMixin(base.ObjectListBase):
             else:
                 setattr(instance, field, value)
 
-        instance._obj_changes = set(
+        instance._changed_fields = set(
             primitive.get('designate_object.changes', []))
         instance._obj_original_values = \
             primitive.get('designate_object.original_values', {})
@@ -359,11 +356,13 @@ class ListObjectMixin(base.ObjectListBase):
 
         return list_
 
-    def __str__(self):
-        return (_("<%(type)s count:'%(count)s' object:'%(list_type)s'>")
-                % {'count': len(self),
-                   'type': self.LIST_ITEM_TYPE.obj_name(),
-                   'list_type': self.obj_name()})
+    def __repr__(self):
+        return ("<%(type)s count:'%(count)s' object:'%(list_type)s'>" %
+                {
+                    'type': self.LIST_ITEM_TYPE.obj_name(),
+                    'count': len(self),
+                    'list_type': self.obj_name()
+                })
 
     def __iter__(self):
         """List iterator interface"""
@@ -485,7 +484,7 @@ class PagedListObjectMixin(object):
 
 class DesignateRegistry(base.VersionedObjectRegistry):
     def registration_hook(self, cls, index):
-        for name, field in six.iteritems(cls.fields):
+        for name, field in cls.fields.items():
             attr = get_dict_attr(cls, name)
 
             def getter(self, name=name):
@@ -507,9 +506,9 @@ class DesignateRegistry(base.VersionedObjectRegistry):
                 self._changed_fields.add(name)
                 # TODO(daidv): _obj_original_values shoud be removed
                 # after OVO migration completed.
-                if (self.obj_attr_is_set(name) and value != getattr(self, name)
-                    and name not in list(six.iterkeys(
-                        self._obj_original_values))):
+                if (self.obj_attr_is_set(name) and
+                        value != getattr(self, name) and
+                        name not in list(self._obj_original_values.keys())):  # noqa
                     self._obj_original_values[name] = getattr(self, name)
                 try:
                     return setattr(self, attrname, field_value)
