@@ -19,6 +19,7 @@ import functools
 import inspect
 import os
 import time
+from unittest import mock
 
 import eventlet
 from oslo_config import cfg
@@ -30,15 +31,14 @@ from testtools import testcase
 
 from designate.common import constants
 import designate.conf
+from designate.context import DesignateContext
 from designate import exceptions
 from designate import objects
 from designate import policy
 from designate import storage
-from designate import utils
-from designate.context import DesignateContext
-from designate.manage import database as manage_database
 from designate.tests import fixtures
 from designate.tests import resources
+from designate import utils
 
 eventlet.monkey_patch(os=False)
 
@@ -356,15 +356,10 @@ class TestCase(base.BaseTestCase):
             group='service:api'
         )
 
-        # The database fixture needs to be set up here (as opposed to isolated
-        # in a storage test case) because many tests end up using storage.
-        REPOSITORY = os.path.abspath(os.path.join(os.path.dirname(__file__),
-                                                  '..', 'storage',
-                                                  'impl_sqlalchemy',
-                                                  'migrate_repo'))
+        self._disable_osprofiler()
+
         self.db_fixture = self.useFixture(
-            fixtures.DatabaseFixture.get_fixture(
-                REPOSITORY, manage_database.INIT_VERSION))
+            fixtures.DatabaseFixture.get_fixture())
 
         if os.getenv('DESIGNATE_SQL_DEBUG', "False").lower() in _TRUE_VALUES:
             connection_debug = 50
@@ -400,6 +395,22 @@ class TestCase(base.BaseTestCase):
         # Setup the Default Pool with some useful settings
         self._setup_default_pool()
 
+    def _disable_osprofiler(self):
+        """Disable osprofiler.
+
+        osprofiler should not run for unit tests.
+        """
+
+        def side_effect(value):
+            return value
+        mock_decorator = mock.MagicMock(side_effect=side_effect)
+        try:
+            p = mock.patch("osprofiler.profiler.trace_cls",
+                           return_value=mock_decorator)
+            p.start()
+        except ModuleNotFoundError:
+            pass
+
     def _setup_default_pool(self):
         # Fetch the default pool
         pool = self.storage.get_pool(self.admin_context, default_pool_id)
@@ -494,11 +505,11 @@ class TestCase(base.BaseTestCase):
 
         return _values
 
-    def get_recordset_fixture(self, zone_name, type='A', fixture=0,
+    def get_recordset_fixture(self, zone_name, recordset_type='A', fixture=0,
                               values=None):
         values = values or {}
 
-        _values = copy.copy(self.recordset_fixtures[type][fixture])
+        _values = copy.copy(self.recordset_fixtures[recordset_type][fixture])
         _values.update(values)
 
         try:
@@ -675,31 +686,30 @@ class TestCase(base.BaseTestCase):
         return self.central_service.create_zone(
             context, objects.Zone.from_dict(values))
 
-    def create_recordset(self, zone, type='A', increment_serial=True,
-                         **kwargs):
+    def create_recordset(self, zone, recordset_type='A', records=None,
+                         increment_serial=True, **kwargs):
         context = kwargs.pop('context', self.admin_context)
         fixture = kwargs.pop('fixture', 0)
 
-        values = self.get_recordset_fixture(zone['name'], type=type,
-                                            fixture=fixture,
-                                            values=kwargs)
+        values = self.get_recordset_fixture(
+            zone['name'],
+            recordset_type=recordset_type, fixture=fixture, values=kwargs
+        )
+
+        recordset = objects.RecordSet.from_dict(values)
+        if records is None:
+            recordset.records = [
+                objects.Record.from_dict(
+                    self.get_record_fixture(recordset_type=recordset_type)
+                )
+            ]
+        else:
+            recordset.records = records
 
         return self.central_service.create_recordset(
-            context, zone['id'], objects.RecordSet.from_dict(values),
-            increment_serial=increment_serial)
-
-    def create_record(self, zone, recordset, increment_serial=True,
-                      **kwargs):
-        context = kwargs.pop('context', self.admin_context)
-        fixture = kwargs.pop('fixture', 0)
-
-        values = self.get_record_fixture(recordset['type'], fixture=fixture,
-                                         values=kwargs)
-
-        return self.central_service.create_record(
-            context, zone['id'], recordset['id'],
-            objects.Record.from_dict(values),
-            increment_serial=increment_serial)
+            context, zone['id'], recordset,
+            increment_serial=increment_serial
+        )
 
     def create_blacklist(self, **kwargs):
         context = kwargs.pop('context', self.admin_context)
