@@ -18,10 +18,10 @@ from unittest import mock
 
 from oslo_log import log as logging
 
-from designate.tests import TestCase
 from designate.notification_handler.nova import NovaFixedHandler
 from designate.tests.test_notification_handler import \
     NotificationHandlerMixin
+from designate.tests import TestCase
 
 LOG = logging.getLogger(__name__)
 
@@ -231,7 +231,7 @@ class NovaFixedHandlerTest(TestCase, NotificationHandlerMixin):
         with mock.patch.object(
                 self.plugin, '_create_or_update_recordset') as finder:
             with mock.patch.object(self.plugin.central_api,
-                                   'create_record'):
+                                   'create_recordset'):
                 finder.return_value = {'id': 'fakeid'}
                 self.plugin.process_notification(
                     self.admin_context.to_dict(),
@@ -248,7 +248,7 @@ class NovaFixedHandlerTest(TestCase, NotificationHandlerMixin):
         with mock.patch.object(
                 self.plugin, '_create_or_update_recordset') as finder:
             with mock.patch.object(self.plugin.central_api,
-                                   'create_record'):
+                                   'create_recordset'):
                 finder.return_value = {'id': 'fakeid'}
                 self.plugin.process_notification(
                     self.admin_context.to_dict(),
@@ -265,7 +265,7 @@ class NovaFixedHandlerTest(TestCase, NotificationHandlerMixin):
         with mock.patch.object(
                 self.plugin, '_create_or_update_recordset') as finder:
             with mock.patch.object(self.plugin.central_api,
-                                   'create_record'):
+                                   'create_recordset'):
                 finder.return_value = {'id': 'fakeid'}
                 self.plugin.process_notification(
                     self.admin_context.to_dict(),
