@@ -16,15 +16,15 @@
 from unittest import mock
 
 import dns.exception
-import oslotest.base
 from oslo_config import cfg
 from oslo_config import fixture as cfg_fixture
+import oslotest.base
 
+from designate import dnsutils
 from designate import exceptions
 from designate import objects
 from designate.tests.unit import utils
 from designate.worker import processing
-from designate.worker import utils as wutils
 from designate.worker.tasks import zone
 
 CONF = cfg.CONF
@@ -167,7 +167,7 @@ class TestZoneActionOnTarget(oslotest.base.BaseTestCase):
         self.context = mock.Mock()
         self.executor = mock.Mock()
 
-    @mock.patch.object(wutils, 'notify')
+    @mock.patch.object(dnsutils, 'notify')
     def test_call_create(self, mock_notify):
         self.zone = objects.Zone(name='example.org.', action='CREATE')
         self.actor = zone.ZoneActionOnTarget(
@@ -185,7 +185,7 @@ class TestZoneActionOnTarget(oslotest.base.BaseTestCase):
             port=53
         )
 
-    @mock.patch.object(wutils, 'notify')
+    @mock.patch.object(dnsutils, 'notify')
     def test_call_update(self, mock_notify):
         self.zone = objects.Zone(name='example.org.', action='UPDATE')
         self.actor = zone.ZoneActionOnTarget(
@@ -203,7 +203,7 @@ class TestZoneActionOnTarget(oslotest.base.BaseTestCase):
             port=53
         )
 
-    @mock.patch.object(wutils, 'notify')
+    @mock.patch.object(dnsutils, 'notify')
     def test_call_delete(self, mock_notify):
         self.zone = objects.Zone(name='example.org.', action='DELETE')
         self.actor = zone.ZoneActionOnTarget(
@@ -217,7 +217,7 @@ class TestZoneActionOnTarget(oslotest.base.BaseTestCase):
 
         mock_notify.assert_not_called()
 
-    @mock.patch.object(wutils, 'notify')
+    @mock.patch.object(dnsutils, 'notify')
     @mock.patch('time.sleep', mock.Mock())
     def test_call_exception_raised(self, mock_notify):
         self.backend.create_zone.side_effect = exceptions.BadRequest()
@@ -250,7 +250,7 @@ class TestSendNotify(oslotest.base.BaseTestCase):
 
         self.executor = mock.Mock()
 
-    @mock.patch.object(wutils, 'notify')
+    @mock.patch.object(dnsutils, 'notify')
     def test_call_notify(self, mock_notify):
         self.zone = objects.Zone(name='example.org.')
         self.actor = zone.SendNotify(
@@ -267,7 +267,7 @@ class TestSendNotify(oslotest.base.BaseTestCase):
             port=53
         )
 
-    @mock.patch.object(wutils, 'notify')
+    @mock.patch.object(dnsutils, 'notify')
     def test_call_notify_timeout(self, mock_notify):
         mock_notify.side_effect = dns.exception.Timeout()
         self.zone = objects.Zone(name='example.org.')
@@ -282,21 +282,6 @@ class TestSendNotify(oslotest.base.BaseTestCase):
             self.actor
         )
 
-    @mock.patch.object(wutils, 'notify')
-    def test_call_dont_notify(self, mock_notify):
-        CONF.set_override('notify', False, 'service:worker')
-
-        self.zone = objects.Zone(name='example.org.')
-        self.actor = zone.SendNotify(
-            self.executor,
-            self.zone,
-            self.target,
-        )
-
-        self.assertTrue(self.actor())
-
-        mock_notify.assert_not_called()
-
 
 class TestZoneActor(oslotest.base.BaseTestCase):
     def setUp(self):
@@ -311,12 +296,6 @@ class TestZoneActor(oslotest.base.BaseTestCase):
             mock.Mock(action='CREATE'),
         )
 
-    def test_invalid_action(self):
-        self.assertRaisesRegexp(
-            exceptions.BadAction, 'Unexpected action: BAD',
-            self.actor._validate_action, 'BAD'
-        )
-
     def test_threshold_from_config(self):
         actor = zone.ZoneActor(
             self.executor, self.context, self.pool, mock.Mock(action='CREATE')
@@ -324,7 +303,7 @@ class TestZoneActor(oslotest.base.BaseTestCase):
 
         self.assertEqual(
             cfg.CONF['service:worker'].threshold_percentage,
-            actor.threshold
+            actor.threshold_percentage
         )
 
     def test_execute(self):
@@ -381,7 +360,7 @@ class TestZonePoller(oslotest.base.BaseTestCase):
         self.context = mock.Mock()
         self.pool = mock.Mock()
         self.zone = mock.Mock(name='example.com.', serial=1)
-        self.threshold = 80
+        self.threshold_percentage = 80
         self.executor = mock.Mock()
         self.poller = zone.ZonePoller(
             self.executor,
@@ -389,11 +368,13 @@ class TestZonePoller(oslotest.base.BaseTestCase):
             self.pool,
             self.zone,
         )
-        self.poller._threshold = self.threshold
+        self.poller._threshold = self.threshold_percentage
 
     def test_constructor(self):
         self.assertTrue(self.poller)
-        self.assertEqual(self.threshold, self.poller.threshold)
+        self.assertEqual(
+            self.threshold_percentage, self.poller.threshold_percentage
+        )
 
     def test_call_on_success(self):
         ns_results = [2] * 8 + [0] * 2
@@ -535,7 +516,7 @@ class TestZonePollerPolling(oslotest.base.BaseTestCase):
         self.context = mock.Mock()
         self.zone = mock.Mock(name='example.com.', action='UPDATE', serial=10)
         self.pool = mock.Mock(nameservers=['ns1', 'ns2'])
-        self.threshold = 80
+        self.threshold_percentage = 80
 
         self.poller = zone.ZonePoller(
             self.executor,
@@ -598,23 +579,28 @@ class TestUpdateStatus(oslotest.base.BaseTestCase):
 
     def test_call_on_delete(self):
         self.task.zone.action = 'DELETE'
+        self.task.zone.status = 'SUCCESS'
+        self.task.zone.serial = 0
 
         self.task()
 
-        self.assertEqual('NONE', self.task.zone.action)
-        self.assertEqual('NO_ZONE', self.task.zone.status)
+        self.assertEqual('DELETE', self.task.zone.action)
+        self.assertEqual('SUCCESS', self.task.zone.status)
         self.assertTrue(self.task.central_api.update_status.called)
 
     def test_call_on_success(self):
+        self.task.zone.action = 'UPDATE'
         self.task.zone.status = 'SUCCESS'
+        self.task.zone.serial = 0
 
         self.task()
 
-        self.assertEqual('NONE', self.task.zone.action)
+        self.assertEqual('UPDATE', self.task.zone.action)
         self.assertTrue(self.task.central_api.update_status.called)
 
     def test_call_central_call(self):
         self.task.zone.status = 'SUCCESS'
+        self.task.zone.serial = 0
 
         self.task()
 
@@ -623,11 +609,13 @@ class TestUpdateStatus(oslotest.base.BaseTestCase):
             self.task.zone.id,
             self.task.zone.status,
             self.task.zone.serial,
+            self.task.zone.action,
         )
 
     def test_call_on_delete_error(self):
         self.task.zone.action = 'DELETE'
         self.task.zone.status = 'ERROR'
+        self.task.zone.serial = 0
 
         self.task()
 
@@ -638,6 +626,7 @@ class TestUpdateStatus(oslotest.base.BaseTestCase):
     def test_call_on_create_error(self):
         self.task.zone.action = 'CREATE'
         self.task.zone.status = 'ERROR'
+        self.task.zone.serial = 0
 
         self.task()
 
@@ -648,6 +637,7 @@ class TestUpdateStatus(oslotest.base.BaseTestCase):
     def test_call_on_update_error(self):
         self.task.zone.action = 'UPDATE'
         self.task.zone.status = 'ERROR'
+        self.task.zone.serial = 0
 
         self.task()
 
@@ -668,11 +658,11 @@ class TestPollForZone(oslotest.base.BaseTestCase):
         self.task._max_retries = 3
         self.task._retry_interval = 2
 
-    @mock.patch.object(zone.wutils, 'get_serial', mock.Mock(return_value=10))
+    @mock.patch.object(dnsutils, 'get_serial', mock.Mock(return_value=10))
     def test_get_serial(self):
         self.assertEqual(10, self.task._get_serial())
 
-        zone.wutils.get_serial.assert_called_with(
+        dnsutils.get_serial.assert_called_with(
             'example.org.',
             'ns.example.org',
             port=53
