@@ -4,6 +4,10 @@
 XTRACE=$(set +o | grep xtrace)
 set +o xtrace
 
+LIBDIR=$DEST/designate/devstack/lib
+
+source $LIBDIR/wsgi
+
 # Get backend configuration
 # -------------------------
 if is_service_enabled designate && [[ -r $DESIGNATE_PLUGINS/backend-$DESIGNATE_BACKEND_DRIVER ]]; then
@@ -11,24 +15,15 @@ if is_service_enabled designate && [[ -r $DESIGNATE_PLUGINS/backend-$DESIGNATE_B
     source $DESIGNATE_PLUGINS/backend-$DESIGNATE_BACKEND_DRIVER
 fi
 
-# Helper Functions
-# ----------------
-function setup_colorized_logging_designate {
-    local conf_file=$1
-    local conf_section=$2
-    local project_var=${3:-"project_name"}
-    local user_var=${4:-"user_name"}
-
-    setup_colorized_logging $conf_file $conf_section $project_var $user_var
-}
-
 # DevStack Plugin
 # ---------------
 
 # cleanup_designate - Remove residual data files, anything left over from previous
 # runs that a clean run would need to clean up
 function cleanup_designate {
-    sudo rm -rf $DESIGNATE_STATE_PATH $DESIGNATE_AUTH_CACHE_DIR
+    sudo rm -rf $DESIGNATE_STATE_PATH
+    sudo rm -f $(apache_site_config_for designate-api)
+    remove_uwsgi_config "$DESIGNATE_UWSGI_CONF" "$DESIGNATE_UWSGI"
     cleanup_designate_backend
 }
 
@@ -45,7 +40,6 @@ function configure_designate {
 
     # General Configuration
     iniset_rpc_backend designate $DESIGNATE_CONF DEFAULT
-    iniset $DESIGNATE_CONF DEFAULT rpc_response_timeout 5
 
     iniset $DESIGNATE_CONF DEFAULT debug $ENABLE_DEBUG_LOG_LEVEL
     iniset $DESIGNATE_CONF DEFAULT state_path $DESIGNATE_STATE_PATH
@@ -64,41 +58,38 @@ function configure_designate {
         iniset $DESIGNATE_CONF coordination backend_url $DESIGNATE_COORDINATION_URL
     fi
 
-    if is_service_enabled designate-pool-manager; then
-        # Pool Manager Configuration
-        iniset $DESIGNATE_CONF service:pool_manager pool_id $DESIGNATE_POOL_ID
-        iniset $DESIGNATE_CONF service:pool_manager cache_driver $DESIGNATE_POOL_MANAGER_CACHE_DRIVER
-        iniset $DESIGNATE_CONF service:pool_manager periodic_recovery_interval $DESIGNATE_PERIODIC_RECOVERY_INTERVAL
-        iniset $DESIGNATE_CONF service:pool_manager periodic_sync_interval $DESIGNATE_PERIODIC_SYNC_INTERVAL
-
-        # Pool Manager Cache
-        if [ "$DESIGNATE_POOL_MANAGER_CACHE_DRIVER" == "sqlalchemy" ]; then
-            iniset $DESIGNATE_CONF pool_manager_cache:sqlalchemy connection `database_connection_url designate_pool_manager`
-        fi
-    fi
+    # Agent Configuration
+    iniset $DESIGNATE_CONF service:agent workers $API_WORKERS
 
     # API Configuration
     sudo cp $DESIGNATE_DIR/etc/designate/api-paste.ini $DESIGNATE_APIPASTE_CONF
     iniset $DESIGNATE_CONF service:api enabled_extensions_v2 $DESIGNATE_ENABLED_EXTENSIONS_V2
     iniset $DESIGNATE_CONF service:api enabled_extensions_admin $DESIGNATE_ENABLED_EXTENSIONS_ADMIN
-    iniset $DESIGNATE_CONF service:api api_base_uri $DESIGNATE_SERVICE_PROTOCOL://$DESIGNATE_SERVICE_HOST:$DESIGNATE_SERVICE_PORT/
+    iniset $DESIGNATE_CONF service:api enable_host_header True
     iniset $DESIGNATE_CONF service:api enable_api_v2 $DESIGNATE_ENABLE_API_V2
     iniset $DESIGNATE_CONF service:api enable_api_admin $DESIGNATE_ENABLE_API_ADMIN
 
+    # Central Configuration
+    iniset $DESIGNATE_CONF service:central workers $API_WORKERS
+
     # mDNS Configuration
     iniset $DESIGNATE_CONF service:mdns listen ${DESIGNATE_SERVICE_HOST}:${DESIGNATE_SERVICE_PORT_MDNS}
+    iniset $DESIGNATE_CONF service:mdns workers $API_WORKERS
+
+    # Producer Configuration
+    iniset $DESIGNATE_CONF service:producer workers $API_WORKERS
+
+    # Sink Configuration
+    iniset $DESIGNATE_CONF service:sink workers $API_WORKERS
 
     # Worker Configuration
-    if ! is_service_enabled designate-pool-manager; then
-        iniset $DESIGNATE_CONF service:worker enabled True
-        iniset $DESIGNATE_CONF service:worker notify True
-        iniset $DESIGNATE_CONF service:worker poll_max_retries $DESIGNATE_POLL_RETRIES
-        iniset $DESIGNATE_CONF service:worker poll_retry_interval $DESIGNATE_POLL_INTERVAL
-    fi
+    iniset $DESIGNATE_CONF service:worker poll_max_retries $DESIGNATE_POLL_RETRIES
+    iniset $DESIGNATE_CONF service:worker poll_retry_interval $DESIGNATE_POLL_INTERVAL
+    iniset $DESIGNATE_CONF service:worker workers $API_WORKERS
 
     # Set up Notifications/Ceilometer Integration
-    iniset $DESIGNATE_CONF DEFAULT notification_driver "$DESIGNATE_NOTIFICATION_DRIVER"
-    iniset $DESIGNATE_CONF DEFAULT notification_topics "$DESIGNATE_NOTIFICATION_TOPICS"
+    iniset $DESIGNATE_CONF oslo_messaging_notifications driver "$DESIGNATE_NOTIFICATION_DRIVER"
+    iniset $DESIGNATE_CONF oslo_messaging_notifications topics "$DESIGNATE_NOTIFICATION_TOPICS"
 
     # Root Wrap
     sudo cp $DESIGNATE_DIR/etc/designate/rootwrap.conf.sample $DESIGNATE_ROOTWRAP_CONF
@@ -115,32 +106,29 @@ function configure_designate {
     sudo chown root:root $tempfile
     sudo mv $tempfile /etc/sudoers.d/designate-rootwrap
 
-    # TLS Proxy Configuration
     if is_service_enabled tls-proxy; then
-        # Set the service port for a proxy to take the original
-        iniset $DESIGNATE_CONF service:api listen ${DESIGNATE_SERVICE_HOST}:${DESIGNATE_SERVICE_PORT_INT}
-    else
-        iniset $DESIGNATE_CONF service:api listen ${DESIGNATE_SERVICE_HOST}:${DESIGNATE_SERVICE_PORT}
+        iniset $DESIGNATE_CONF keystone cafile $SSL_BUNDLE_FILE
     fi
 
     # Setup the Keystone Integration
     if is_service_enabled keystone; then
         iniset $DESIGNATE_CONF service:api auth_strategy keystone
-        configure_auth_token_middleware $DESIGNATE_CONF designate $DESIGNATE_AUTH_CACHE_DIR
+        configure_keystone_authtoken_middleware $DESIGNATE_CONF designate
+        iniset $DESIGNATE_CONF keystone region_name $REGION_NAME
+        iniset $DESIGNATE_CONF service:api quotas_verify_project_id True
     fi
 
     # Logging Configuration
-    if [ "$USE_SYSTEMD" != "False" ]; then
-        setup_systemd_logging $DESIGNATE_CONF
-    fi
-
-    # Format logging
-    if [ "$LOG_COLOR" == "True" ] && [ "$USE_SYSTEMD" == "False" ]; then
-        setup_colorized_logging_designate $DESIGNATE_CONF DEFAULT "tenant" "user"
-    fi
+    setup_systemd_logging $DESIGNATE_CONF
 
     # Backend Plugin Configuation
     configure_designate_backend
+
+    if [[ "$DESIGNATE_WSGI_MODE" == "uwsgi" ]]; then
+        designate_configure_uwsgi
+    else
+        designate_configure_mod_wsgi
+    fi
 }
 
 function configure_designatedashboard {
@@ -161,18 +149,17 @@ function configure_designate_tempest() {
         iniset $TEMPEST_CONFIG dns_feature_enabled api_admin $DESIGNATE_ENABLE_API_ADMIN
         iniset $TEMPEST_CONFIG dns_feature_enabled api_v2_root_recordsets True
         iniset $TEMPEST_CONFIG dns_feature_enabled api_v2_quotas True
+        iniset $TEMPEST_CONFIG dns_feature_enabled api_v2_quotas_verify_project True
         iniset $TEMPEST_CONFIG dns_feature_enabled bug_1573141_fixed True
+        iniset $TEMPEST_CONFIG dns_feature_enabled bug_1932026_fixed True
 
         # Tell tempest where are nameservers are.
         nameservers=$DESIGNATE_SERVICE_HOST:$DESIGNATE_SERVICE_PORT_DNS
         # TODO(kiall): Remove hardcoded list of plugins
         case $DESIGNATE_BACKEND_DRIVER in
-            bind9|powerdns)
+            bind9)
                 nameservers="$DESIGNATE_SERVICE_HOST:$DESIGNATE_SERVICE_PORT_DNS"
                 ;;
-            akamai)
-                nameservers="$DESIGNATE_AKAMAI_NAMESERVERS"
-                ;;
             dynect)
                 nameservers="$DESIGNATE_DYNECT_NAMESERVERS"
                 ;;
@@ -198,17 +185,20 @@ function create_designate_accounts {
     if is_service_enabled designate-api; then
         create_service_user "designate"
 
+        local designate_api_url="$DESIGNATE_SERVICE_PROTOCOL://$DESIGNATE_SERVICE_HOST/dns"
+
         get_or_create_service "designate" "dns" "Designate DNS Service"
-        get_or_create_endpoint "dns" \
+        get_or_create_endpoint \
+            "dns" \
             "$REGION_NAME" \
-            "$DESIGNATE_SERVICE_PROTOCOL://$DESIGNATE_SERVICE_HOST:$DESIGNATE_SERVICE_PORT/"
+            "$designate_api_url"
     fi
 }
 
 # create_designate_pool_configuration - Create Pool Configuration
 function create_designate_pool_configuration {
     # Sync Pools Config
-    designate-manage pool update --file $DESIGNATE_CONF_DIR/pools.yaml
+    $DESIGNATE_BIN_DIR/designate-manage pool update --file $DESIGNATE_CONF_DIR/pools.yaml
 
     # Allow Backends to do backend specific tasks
     if function_exists create_designate_pool_configuration_backend; then
@@ -218,44 +208,36 @@ function create_designate_pool_configuration {
 
 # init_designate - Initialize etc.
 function init_designate {
-    # Create cache dir
-    sudo mkdir -p $DESIGNATE_AUTH_CACHE_DIR
-    sudo chown $STACK_USER $DESIGNATE_AUTH_CACHE_DIR
-    rm -f $DESIGNATE_AUTH_CACHE_DIR/*
-
-    # Some Designate Backends require mdns be bound to port 53, make that
-    # doable.
-    sudo setcap 'cap_net_bind_service=+ep' $(readlink -f /usr/bin/python)
-
     # (Re)create designate database
     recreate_database designate utf8
 
     # Init and migrate designate database
-    designate-manage database sync
-
-    if [ "$DESIGNATE_POOL_MANAGER_CACHE_DRIVER" == "sqlalchemy" ]; then
-        # (Re)create designate_pool_manager cache
-        recreate_database designate_pool_manager utf8
-
-        # Init and migrate designate pool-manager-cache
-        designate-manage pool-manager-cache sync
-    fi
+    $DESIGNATE_BIN_DIR/designate-manage database sync
 
     init_designate_backend
 }
 
 # install_designate - Collect source and prepare
 function install_designate {
-    if is_ubuntu; then
-        install_package libcap2-bin
-    elif is_fedora; then
+    if [[ "$DESIGNATE_WSGI_MODE" == "uwsgi" ]]; then
+        install_apache_uwsgi
+    else
+        install_apache_wsgi
+    fi
+
+    if is_fedora; then
         # bind-utils package provides `dig`
-        install_package libcap bind-utils
+        install_package bind-utils
     fi
 
     git_clone $DESIGNATE_REPO $DESIGNATE_DIR $DESIGNATE_BRANCH
     setup_develop $DESIGNATE_DIR
 
+    # Install reqs for tooz driver
+    if [[ "$DESIGNATE_COORDINATION_URL" =~ "memcached" ]]; then
+        pip_install_gr "pymemcache"
+    fi
+
     install_designate_backend
 }
 
@@ -275,7 +257,6 @@ function install_designatedashboard {
     setup_dev_lib "designate-dashboard"
 
     for panel in _1710_project_dns_panel_group.py \
-                 _1720_project_dns_panel.py \
                  _1721_dns_zones_panel.py \
                  _1722_dns_reversedns_panel.py; do
         ln -fs $DESIGNATEDASHBOARD_DIR/designatedashboard/enabled/$panel $HORIZON_DIR/openstack_dashboard/local/enabled/$panel
@@ -293,36 +274,42 @@ function start_designate {
     start_designate_backend
 
     run_process designate-central "$DESIGNATE_BIN_DIR/designate-central --config-file $DESIGNATE_CONF"
-    run_process designate-api "$DESIGNATE_BIN_DIR/designate-api --config-file $DESIGNATE_CONF"
     run_process designate-mdns "$DESIGNATE_BIN_DIR/designate-mdns --config-file $DESIGNATE_CONF"
     run_process designate-agent "$DESIGNATE_BIN_DIR/designate-agent --config-file $DESIGNATE_CONF"
     run_process designate-sink "$DESIGNATE_BIN_DIR/designate-sink --config-file $DESIGNATE_CONF"
-    if is_service_enabled designate-pool-manager; then
-        run_process designate-pool-manager "$DESIGNATE_BIN_DIR/designate-pool-manager --config-file $DESIGNATE_CONF"
-        run_process designate-zone-manager "$DESIGNATE_BIN_DIR/designate-zone-manager --config-file $DESIGNATE_CONF"
+
+    run_process designate-worker "$DESIGNATE_BIN_DIR/designate-worker --config-file $DESIGNATE_CONF"
+    run_process designate-producer "$DESIGNATE_BIN_DIR/designate-producer --config-file $DESIGNATE_CONF"
+
+
+
+    if [[ "$DESIGNATE_WSGI_MODE" == "uwsgi" ]]; then
+        run_process "designate-api" "$(which uwsgi) --procname-prefix designate-api --ini $DESIGNATE_UWSGI_CONF"
+        enable_apache_site designate-api-wsgi
+        restart_apache_server
     else
-        run_process designate-worker "$DESIGNATE_BIN_DIR/designate-worker --config-file $DESIGNATE_CONF"
-        run_process designate-producer "$DESIGNATE_BIN_DIR/designate-producer --config-file $DESIGNATE_CONF"
+        enable_apache_site designate-api
+        restart_apache_server
     fi
 
-
-
-    # Start proxies if enabled
-    if is_service_enabled designate-api && is_service_enabled tls-proxy; then
-        start_tls_proxy designate-api '*' $DESIGNATE_SERVICE_PORT $DESIGNATE_SERVICE_HOST $DESIGNATE_SERVICE_PORT_INT &
-    fi
-
-    if ! timeout $SERVICE_TIMEOUT sh -c "while ! wget --no-proxy -q -O- $DESIGNATE_SERVICE_PROTOCOL://$DESIGNATE_SERVICE_HOST:$DESIGNATE_SERVICE_PORT; do sleep 1; done"; then
-        die $LINENO "Designate did not start"
+    echo "Waiting for designate-api to start..."
+    if ! wait_for_service $SERVICE_TIMEOUT $DESIGNATE_SERVICE_PROTOCOL://$DESIGNATE_SERVICE_HOST/dns; then
+        die $LINENO "designate-api did not start"
     fi
 }
 
 # stop_designate - Stop running processes
 function stop_designate {
+    if [[ "$DESIGNATE_WSGI_MODE" == "uwsgi" ]]; then
+        stop_process "designate-api"
+        disable_apache_site designate-api-wsgi
+        restart_apache_server
+    else
+        disable_apache_site designate-api
+        restart_apache_server
+    fi
+
     stop_process designate-central
-    stop_process designate-api
-    stop_process designate-pool-manager
-    stop_process designate-zone-manager
     stop_process designate-mdns
     stop_process designate-agent
     stop_process designate-sink
@@ -345,7 +332,7 @@ if is_service_enabled designate; then
         install_designateclient
 
         echo_summary "Installing Designate"
-        install_designate
+        stack_install_service designate
 
         if is_service_enabled horizon; then
             echo_summary "Installing Designate dashboard"
